function FullSampleStrMat = CreateFullSample(DSGEModel)
% CreateFullSample: Creates a string matrix with the full sample of dates.
%
% USAGE:
%
%       FullSampleStrMat = CreateFullSample(DSGEModel)
%
% REQUIRED INPUT:  DSGEModel (structure) with fields containing all the information about a DSGE Model for YADA.
%
% REQUIRED OUTPUT: FullSampleStrMat (string matrix) with the full sample of dates.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: February 25, 2010.
%                        This version: January 8, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 26-02-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 03-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 27-01-2014: Updated the documentation.
%
% * 12-01-2015: Updated the documentation.
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
% * 11-01-2018: Updated the documentation.
%
% * 21-01-2019: Updated the documentation.
%
% * 08-01-2020: Updated the documentation.
%
% * 25-01-2021: Updated the documentation.
%
% * 04-01-2022: Updated the documentation.
%
% * 03-01-2023: Updated the documentation.
%
% * 08-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% collect information
%
BeginYear = str2num(DSGEModel.BeginYear);
BeginPeriod = str2num(DSGEModel.BeginPeriod);
EndYear = str2num(DSGEModel.EndYear);
EndPeriod = str2num(DSGEModel.EndPeriod);
if strcmp(DSGEModel.DataFrequency,'q')==1;
   SampleFreq = 4;
elseif strcmp(DSGEModel.DataFrequency,'m')==1;
   SampleFreq = 12;
elseif strcmp(DSGEModel.DataFrequency,'a')==1;
   SampleFreq = 1;
end;
%
% create a full sample string matrix
%
FullSampleStrMat = '';
for i=BeginYear:EndYear;
   for j=1:SampleFreq;
      if i==BeginYear;
         if j>=BeginPeriod;
            FullSampleStrMat = strvcat(FullSampleStrMat,[int2str(i) ':' int2str(j)]);
         end;
      elseif i==EndYear;
         if j<=EndPeriod;
            FullSampleStrMat = strvcat(FullSampleStrMat,[int2str(i) ':' int2str(j)]);
         end;
      else;
         FullSampleStrMat = strvcat(FullSampleStrMat,[int2str(i) ':' int2str(j)]);
      end;
   end;
end;

%
% end of CreateFullSample.m
%
