function ModelFiles = RemoveFromModelFiles(ModelFiles,RemoveModelFile)
% RemoveFromModelFiles: Removes a specified row from a string matrix.
%
% USAGE:
%
%       ModelFiles = RemoveFromModelFiles(ModelFiles,RemoveModelFile)
%
% REQUIRED INPUT:  ModelFiles (string matrix)
%
%                  RemoveModelFile (string vector) that should be removed from
%                                  ModelFiles.
%
% REQUIRED OUTPUT: ModelFiles (string matrix)
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: January 25, 2007.
%                        This version: January 8, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 13-11-2007: Updated the documentation.
%
% * 23-05-2008: Updated the documentation.
%
% * 19-12-2008: Updated the documentation.
%
% * 02-05-2009: Updated the documentation.
%
% * 05-01-2010: Updated the documentation.
%
% * 04-01-2011: Updated the documentation.
%
% * 03-01-2012: Updated the documentation.
%
% * 02-01-2013: Updated the documentation.
%
% * 24-01-2014: Updated the documentation.
%
% * 05-01-2015: Updated the documentation.
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
% * 08-01-2018: Updated the documentation.
%
% * 21-01-2019: Updated the documentation.
%
% * 07-01-2020: Updated the documentation.
%
% * 25-01-2021: Updated the documentation.
%
% * 04-01-2022: Updated the documentation.
%
% * 03-01-2023: Updated the documentation.
%
% * 08-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if size(ModelFiles,1)==1;
   if strcmp(lower(StringTrim(ModelFiles)),lower(StringTrim(RemoveModelFile)))==1;
      ModelFiles = '';
   end;
   return;
end;
%
% we need to create a new output string matrix
%
NewModelFiles = '';
for i=1:size(ModelFiles,1);
   if strcmp(lower(StringTrim(ModelFiles(i,:))),lower(StringTrim(RemoveModelFile)))==0;
       NewModelFiles = strvcat(NewModelFiles,StringTrim(ModelFiles(i,:)));
   end;
end;
ModelFiles = NewModelFiles;

%
% end of RemoveFromModelFiles.m
%
