function [a,b] = MomentToParamGumbelPDF(mu,sigma)
% MomentToParamGumbelPDF: Transforms the mean and the standard deviation to the location
%                           and scale parameters of the Gumbel distribution.
%
% USAGE:
%
%       [a,b] = MomentToParamGumbelPDF(mu,sigma)
%
% REQUIRED INPUT:  mu (vector) with the mean of the Gumbel distribution.
%
%                  sigma (vector) with the standard deviation of the Gumbel distribution.
%
% REQUIRED OUTPUT: a (vector) with the location parameter of the Gumbel distribution.
%
%                  b (vector) with the scale parameter of the Gumbel distribution.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: April 2, 2009.
%                        This version: January 8, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 03-04-2009: Added the call to DiGamma in case the psi-function is unavailable or
%               not a mex-file.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 02-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 27-01-2014: Updated the documentation.
%
% * 13-01-2015: Updated the documentation.
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
% * 12-01-2018: Updated the documentation.
%
% * 21-01-2019: Updated the documentation.
%
% * 08-01-2020: Updated the documentation.
%
% * 25-01-2021: Updated the documentation.
%
% * 04-01-2022: Updated the documentation.
%
% * 03-01-2023: Updated the documentation.
%
% * 08-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

b = (sqrt(6)/pi)*sigma;
if exist('psi')==3;
   a = mu+(psi(1)*b);
else;
   a = mu+(DiGamma(1)*b);
end;

%
% end of MomentToParamGumbelPDF.m
%
