// The An-Schorfheide nonlinear dynare mod file

// model variables
var yhat pihat chat rhat ghat zhat yhatlag;

// exogenous variables (shocks)
varexo etaR etaG etaZ;

// parameters
parameters tau beta kappa gammaQ piA rA rhoR psi1 psi2 sigmaR rhoG sigmaG rhoZ sigmaZ v g;
// initial values
tau = 1.875;
kappa = 0.15;
psi1 = 1.4583;
psi2 = 0.375;
rhoR = 0.5;
rhoG = 0.8462;
rhoZ = 0.7059;
rA = 0.5;
piA = 6.4286;
gammaQ = 0.4;
sigmaR = 0.00358;
sigmaG = 0.00895;
sigmaZ = 0.00447;
beta = 1/(1+(rA/400));
v = 0.1;
g = 1/0.85;

// model equations
model;
1/beta = exp(-tau*chat(+1)+tau*chat+rhat-zhat(+1)-pihat(+1));

(kappa/tau)*(exp(tau*chat) - 1) = (exp(pihat) - 1)*( (1-(1/(2*v)))*exp(pihat) + (1/(2*v)) ) -
   beta*(exp(pihat(+1))-1)*exp( -tau*chat(+1) + tau*chat + yhat(+1) - yhat + pihat(+1) );

exp(chat - yhat) = exp(-ghat) - (tau*(1-v)*g/(2*v*kappa))*(exp(pihat)-1)^2;

// policy equation is already log-linearized
rhat = rhoR*rhat(-1) + (1-rhoR)*psi1*pihat + (1-rhoR)*psi2*yhat - (1-rhoR)*psi2*ghat + sigmaR*etaR;

// shock processes
ghat = rhoG*ghat(-1) + sigmaG*etaG;

zhat = rhoZ*zhat(-1) + sigmaZ*etaZ;

yhatlag = yhat(-1);

end;

steady;


shocks;
var    etaR; 
stderr 1;
var    etaG;
stderr 1;
var    etaZ;
stderr 1;
end;

stoch_simul(aim_solver,periods=500,irf=0,order=1,nomoments) yhat pihat chat rhat ghat zhat yhatlag;

// end of ASNonLinearDynare.mod file


