function TextGUICopy
% TextGUICopy: Copies the text from the TextGUI window to the clipboard.
%
% USAGE:
%
%       TextGUICopy
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: July 25, 2006.
%                        This version: January 8, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 02-04-2008: Updated the documentation.
%
% * 23-05-2008: Updated the documentation.
%
% * 19-12-2008: Updated the documentation.
%
% * 02-05-2009: Updated the documentation.
%
% * 06-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 04-01-2012: Updated the documentation.
%
% * 02-01-2013: Updated the documentation.
%
% * 24-01-2014: Updated the documentation.
%
% * 05-01-2015: Updated the documentation.
%
% * 08-06-2015: The code takes the groot function into account.
%
% * 09-06-2015: The code now takes gcf into account.
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
% * 08-01-2018: Updated the documentation.
%
% * 18-01-2019: Updated the documentation.
%
% * 07-01-2020: Updated the documentation.
%
% * 25-01-2021: Updated the documentation.
%
% * 03-01-2022: Updated the documentation.
%
% * 02-01-2023: Updated the documentation.
%
% * 08-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if exist('groot')==0;
   GraphicsRoot = 0;
else;
   GraphicsRoot = groot;
end;
TextControls = get(gcf,'UserData');
TextStr = get(TextControls.text,'String');
%
fig = figure('Color',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
   'FileName','TextGUICopy.m', ...
   'MenuBar','none', ...
   'PaperUnits','points', ...
   'Units','pixels', ...
   'Position',[0 0 800 600], ...
   'Tag','Temp', ...
   'Name','temp', ...
   'NumberTitle','off', ...
   'MenuBar','none', ...
   'Visible','off', ...
   'ToolBar','none');
%
textaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[16 16 768 568], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisText', ...
         'XColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'));
%
TextHandle = text('Parent',textaxes,'Position',[0 0.5],'String',TextStr,'FontSize',8,'HorizontalAlignment','left','Interpreter','none','Editing','on');
editmenufcn(fig,'EditSelectAll');
editmenufcn(fig,'EditCopy');
close(fig);

%
% end of TextGUICopy.m
%
