function SetXTickIntegers(AxesHandle)
% SetXTickIntegers: sets the xlabel ticks to intgeger values only.
%
% USAGE:
%
%       SetXTickIntegers(AxesHandle)
%
% REQUIRED INPUT: AxesHandle (handle) to an axis object.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: November 9, 2007.
%                        This version: January 8, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 11-01-2008: Made sure that "XTickMode" is always set to "manual".
%
% * 14-01-2008: If the difference between the max and the min of XTick is less than
%               6, then unit ticks are given.
%
% * 23-05-2008: Updated the documentation.
%
% * 19-12-2008: Updated the documentation.
%
% * 02-05-2009: Updated the documentation.
%
% * 06-01-2010: Updated the documentation.
%
% * 02-07-2010: Swapped the ceil and floor functions when creating the "NewXTick" vector.
%
% * 05-01-2011: Updated the documentation.
%
% * 03-01-2012: Updated the documentation.
%
% * 02-01-2013: Updated the documentation.
%
% * 24-01-2014: Updated the documentation.
%
% * 05-01-2015: Updated the documentation.
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
% * 08-01-2018: Updated the documentation.
%
% * 21-01-2019: Updated the documentation.
%
% * 07-01-2020: Updated the documentation.
%
% * 25-01-2021: Updated the documentation.
%
% * 03-01-2022: Updated the documentation.
%
% * 06-08-2022: Made sure that graphs with few years get a sufficient number of tick marks.
%
% * 03-01-2023: Updated the documentation.
%
% * 06-02-2023: Made sure that graphs with fewer than two ticks get some at least two ticks.
%
% * 08-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% check if we need to fix the X ticks
%
set(AxesHandle,'XTickMode','manual');
XTick = get(AxesHandle,'XTick');
XLim = get(AxesHandle,'XLim');
XTickCheck = 0;
if length(XTick)<2;
   XTick = [floor(XLim(1)) ceil(XLim(2))];
end;
if (floor(XLim(2))<=max(XTick))|(((XTick(2)-XTick(1))<(XLim(2)-XLim(1)))&(XLim(2)-XLim(1)>10));
   if length(XTick)>1;
      if (IsInteger(XTick(2)-XTick(1))==1)&(max(XTick)-min(XTick)>=6);
         XTickCheck = 1;
      end;
   else;
      if IsInteger(XTick(1))==1;
         XTickCheck = 1;
      end;
   end;
   if XTickCheck==1;
      %
      % no need to fix anything
      %
      return;
   end;
   %
   % create the new XTick vector and XTickLabel string matrix
   %
   NewXTick = (floor(XTick(1)):1:ceil(XTick(length(XTick))));
else;
   NewXTick = (floor(XLim(1)):1:ceil(XLim(2)));
end;
%
% set the new features on the axes
%
set(AxesHandle,'XTick',NewXTick);

%
% end of SetXTickIntegers.m
%
