function SetYADAIcon(FigHandle,ShowYADAIcon)
% SetYADAIcon: Sets the YADA alarm clock icon as the window icon if supported by
%              the matlab version.
%
% USAGE:
%
%       SetYADAIcon(FigHandle,ShowYADAIcon)
%
% REQUIRED INPUT: FigHandle (handle) to the window where the YADA icon should be set.
%
%                 ShowYADAIcon (boolean) that takes the value 1 if the user wants the
%                              YADA icon to be displayed and 0 otherwise.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: June 19, 2023.
%                        This version: January 9, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 20-06-2023: Updated the documentation.
%
% * 09-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

yadaicon = FixFilePath([pwd '\icons\yada.gif']);
if (ShowYADAIcon==1)&(exist('isjava')==5)&(IsHandle(FigHandle)==1)&(FileExist(yadaicon)==1)&(FileExist(FixFilePath([pwd '\addons\ovs\OVSFunctions.m']))==1);
   try;
      jframe = get(FigHandle,'javaframe');
      figIcon = javax.swing.ImageIcon(yadaicon);
      jframe.setFigureIcon(figIcon);
   catch;
      % do nothing
   end;
end;

%
% SetYADAIcon.m
%
