function status = IsHandle(x)
% IsHandle: tests if the input is a handle of a figure or not. Allows for empty input.
%
% USAGE:
%
%       status = IsHandle(x)
%
% REQUIRED INPUT:  x (vector) of dimension k.
%
% REQUIRED OUTPUT: status (boolean vector) of dimension k with 1 in element i is a handle
%                         and 0 otherwise.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: March 17, 2015.
%                        This version: January 16, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 18-03-2015: Updated the documentation.
%
% * 11-06-2015: Attempting to make it work properly with matlab 2014b and later.
%
% * 23-06-2015: The function now calls isgraphics with the type 'Figure' if the function exists.
%
% * 08-09-2015: Deleted the previous changes as they are wrong.
%
% * 22-01-2016: Updated the documentation.
%
% * 21-03-2017: Updated the documentation.
%
% * 17-01-2018: Updated the documentation.
%
% * 22-01-2019: Updated the documentation.
%
% * 09-01-2020: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 05-01-2022: Updated the documentation.
%
% * 05-01-2023: Updated the documentation.
%
% * 16-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if isempty(x)==1;
   status = 0;
   return;
end;
status = ishandle(x);

%
% end of IsHandle.m
%
