function VerifyProjectMenu(DSGEModel,controls)
% VerifyProjectMenu: Enables and disables items on the project menu
%
% USAGE:
%
%       VerifyProjectMenu(DSGEModel,controls)
%
% REQUIRED INPUT: DSGEModel (structure) whose fields contain all required information
%                           about the model, such as input files, variable and sample
%                           data. Actual observations are not stored in this file.
%
%                 controls (structure) with the handles to all controls on the main
%                           YADA dialog.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: June 9, 2009.
%                        This version: January 19, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 14-07-2009: Updated the documentation.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 11-01-2011: Made sure that "ModeFile" and "PriorDrawsFile" supports unix and mac paths.
%
% * 05-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 27-01-2014: Updated the documentation.
%
% * 13-01-2015: Updated the documentation.
%
% * 22-02-2016: Updated the documentation.
%
% * 22-03-2017: Updated the documentation.
%
% * 14-05-2018: Updated the documentation.
%
% * 25-10-2018: Made sure that the name of the prior draws file reflects using a system prior.
%
% * 24-01-2019: Updated the documentation.
%
% * 10-01-2020: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 06-01-2022: Updated the documentation.
%
% * 06-01-2023: Updated the documentation.
%
% * 19-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% enable and disable the controls defined in ProjectMenu.m
%
% 1. initial values
%
if VerifyPosteriorModeEstimation(DSGEModel)==1;
   set(controls.project.spatdist.initialvalues,'Enable','on');
else;
   set(controls.project.spatdist.initialvalues,'Enable','off');
end;
%
% 2. prior distribution
%
if FileExist(DSGEModel.SystemPriorFile)==0;
   PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
else;
   PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
end;
if FileExist(PriorDrawsFile)==1;
   set(controls.project.spatdist.prior,'Enable','on');
else;
   set(controls.project.spatdist.prior,'Enable','off');
end;
%
% 3. posterior mode
%
ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
if FileExist(ModeFile)==1;
   set(controls.project.spatdist.postmode,'Enable','on');
else;
   set(controls.project.spatdist.postmode,'Enable','off');
end;
%
% 4. posterior distribution
%
if VerifyDSGEPosteriorDraws(DSGEModel,1,controls)==1;
   set(controls.project.spatdist.posterior,'Enable','on');
else;
   set(controls.project.spatdist.posterior,'Enable','off');
end;

%
% end of VerifyProjectMenu.m
%
