function z = YADArandi(IntMin,IntMax,NumDraws)
% YADArandi: Draws a vector with integers between IntMin and IntMax
%            from a uniform discrete distribution.
%
% USAGE:
%
%       z = YADArandi(IntMin,IntMax,NumDraws)
%
% REQUIRED INPUT:  IntMin (integer) with the minimum integer value.
%
%                  IntMax (integer) with the maximum integer value.
%
% OPTIONAL INPUT:  NumDraws (integer) with the number of draws of z.
%
% REQUIRED OUTPUT: z (vector) of dimension 1xNumDraws
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: April 18, 2017.
%                        This version: January 19, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 19-04-2017: Updated the documentation.
%
% * 15-05-2018: Updated the documentation.
%
% * 24-01-2019: Updated the documentation.
%
% * 10-01-2020: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 06-01-2022: Updated the documentation.
%
% * 06-01-2023: Updated the documentation.
%
% * 19-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if nargin==2;
   NumDraws = 1;
end;
NumDraws = floor(NumDraws);
if NumDraws<1;
   NumDraws = 1;
end;
if exist('randi')~=0;
   z = randi([IntMin IntMax],1,NumDraws);
else;
   %
   % we draw from a uniform distribution between IntMin and IntMax+1
   % and use the floor function to create integers from these draws
   %
   z = floor(UniformRndFcn(IntMin,IntMax+1,NumDraws));
   if any(z>IntMax);
      z(z>IntMax) = IntMax;
   end;
end;

%
% end of YADArandi.m
%
