function [status,VarStrMat] = CompareVariablesStrMat(FirstStrMat,SecondStrMat)
% CompareVariablesStrMat: compares the rows in two string matrices and check if the entries
%                         are equal or not.
%
% USAGE:
%
%       [status,VarStrMat] = CompareVariablesStrMat(FirstStrMat,SecondStrMat)
%
% REQUIRED INPUT:  FirstStrMat (string matrix) of dimension n x n1.
%
%                  SecondStrMat (string matrix) of dimension m x m1
%
% REQUIRED OUTPUT: status (boolean) that takes the value 1 if there is at least one case
%                         sensitive match and 0 otherwise.
%
%                  VarStrMat (string matrix) with the matching entries.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: February 6, 2006.
%                        This version: February 7, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 07-02-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%


%
% initialize
%
status = 0;
VarStrMat = '';
%
[n,n1] = size(FirstStrMat);
[m,m1] = size(SecondStrMat);
for i=1:n;
   FirstRow = StringTrim(FirstStrMat(i,:));
   for j=1:m;
      SecondRow = StringTrim(SecondStrMat(j,:));
      if strcmp(FirstRow,SecondRow)==1;
         VarStrMat = strvcat(VarStrMat,FirstRow);
         break;
      end;
   end;
end;
if isempty(VarStrMat)==0;
   status = 1;
end;

%
% end of CompareVariablesStrMat.m
%
