function outstr = vecstr(instr,addon)
% vecstr: creates a string vector from a string matrix.
%
% USAGE:
%
%       outstr = vecstr(instr,addon)
%
% REQUIRED INPUT:  instr (string matrix) of dimension nxk.
%
% OPTIONAL INPUT:  addon (string vector) with possible characters to use for separating the
%                        rows in instr. Default is an empty string.
%
% REQUIRED OUTPUT: outstr (string vector) with 1 row containg all the rows of instr.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: August 18, 2006.
%                        This version: January 19, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 07-11-2007: Updated the documentation.
%
% * 23-05-2008: Updated the documentation.
%
% * 22-01-2009: Updated the documentation.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 05-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 22-02-2016: Updated the documentation.
%
% * 22-03-2017: Updated the documentation.
%
% * 15-50-2018: Updated the documentation.
%
% * 24-01-2019: Updated the documentation.
%
% * 21-01-2020: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 06-01-2022: Updated the documentation.
%
% * 06-01-2023: Updated the documentation.
%
% * 19-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if nargin<2;
   addon = '';
end;
outstr = '';
if ischar(instr)==1;
   [n k] = size(instr);
   for i=1:n;
      outstr = [outstr StringTrim(instr(i,:)) addon];
   end;
   outstr = StringTrim(outstr);
end;

%
% end of vecstr.m
%
